@@ -139,6 +139,10 @@ g_usb_device_error_quark(void);
 
 const gchar *
 g_usb_device_get_platform_id(GUsbDevice *self);
+gboolean
+g_usb_device_is_emulated(GUsbDevice *self);
+GDateTime *
+g_usb_device_get_created(GUsbDevice *self);
 GUsbDevice *
 g_usb_device_get_parent(GUsbDevice *self);
 GPtrArray *
@@ -170,6 +174,15 @@ g_usb_device_get_device_subclass(GUsbDevice *self);
 guint8
 g_usb_device_get_device_protocol(GUsbDevice *self);
 
+void
+g_usb_device_add_tag(GUsbDevice *self, const gchar *tag);
+void
+g_usb_device_remove_tag(GUsbDevice *self, const gchar *tag);
+gboolean
+g_usb_device_has_tag(GUsbDevice *self, const gchar *tag);
+GPtrArray *
+g_usb_device_get_tags(GUsbDevice *self);
+
 guint8
 g_usb_device_get_configuration_index(GUsbDevice *self);
 guint8
@@ -196,6 +209,8 @@ g_usb_device_get_interfaces(GUsbDevice *self, GError **error);
 
 GPtrArray *
 g_usb_device_get_events(GUsbDevice *self);
+void
+g_usb_device_clear_events(GUsbDevice *self);
 
 GPtrArray *
 g_usb_device_get_bos_descriptors(GUsbDevice *self, GError **error);
